@@ -1,5 +1,5 @@
-"""Top-level package for Borehole Transformations."""
+"""Top-level package for Drillcore Transformations."""
 
 __author__ = """Nikolas Ovaskainen"""
 __email__ = 'nikolasovaskainen@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.2.5'
